.. python-tldap documentation master file, created by
   sphinx-quickstart on Mon Feb  3 09:23:20 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

python-tldap's documentation
============================

:Date: |today|
:Version: |version|

Contents:

.. toctree::
    :maxdepth: 2

    getting_started
    history
    future

Appendices:

.. toctree::
    :maxdepth: 1

    changes
    modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

